@@ -184,7 +184,9 @@ class Project(object):
                 model['teeth'].append({
                     'id': None,
                     'fdi': tooth.fdi,
-                    'type': tooth.type
+                    'type': tooth.type,
+                    'implant_type': None,
+                    'implant_system': None
                 })
 
         return order
