@@ -92,7 +92,8 @@ def handleConnection(websocket: ServerConnection, project: Project, host: str, t
         confirmNewOrder(websocket)
         thread.closeWebsocketServer()
     except:
-        thread.closeWebsocketServer(success=False)
+        sendErrorMessage(websocket)
+        thread.closeWebsocketServer()
         raise
 
 def getAuthentificationToken(websocket: ServerConnection) -> str:
@@ -176,4 +177,9 @@ def confirmNewOrder(websocket: ServerConnection) -> None:
     """
     websocket.send(json.dumps({
         'type': 'confirmNewOrder'
+    }))
+
+def sendErrorMessage(websocket: ServerConnection) -> None:
+    websocket.send(json.dumps({
+        'type': 'error'
     }))
\ No newline at end of file
